@@ -4,26 +4,20 @@
     global url patterns
     ~~~~~~~~~~~~~~~~~~~
 
-
-    Last commit info:
-    ~~~~~~~~~~~~~~~~~
-    $LastChangedDate$
-    $Rev$
-    $Author:$
-
-    :copyleft: 2009 by the PyLucid team, see AUTHORS for more details.
+    :copyleft: 2009-2011 by the PyLucid team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
 from django.conf import settings
 from django.conf.urls.defaults import patterns, url, include
-
 from django.contrib import admin
+from django.http import HttpResponse
+from django.views.defaults import server_error, page_not_found
 
 
 # TODO: Use own error views?
-handler500 = "django.views.defaults.server_error"
-handler404 = "django.views.defaults.page_not_found"
+handler500 = server_error
+handler404 = page_not_found
 
 
 admin.autodiscover()
@@ -46,6 +40,15 @@ urlpatterns = patterns('',
     url(r'^%s/' % settings.ADMIN_URL_PREFIX, include(admin.site.urls)),
 )
 
+# Return a robots.txt that disallows all spiders when DEBUG is True.
+if settings.DEBUG:
+    urlpatterns += patterns("",
+        url(
+            "^robots.txt$",
+            lambda r: HttpResponse("User-agent: *\nDisallow: /", mimetype="text/plain")
+        ),
+    )
+
 # serve static files
 if settings.SERVE_STATIC_FILES:
     # Should only enabled, if the django development server used.
